module Feature.Generation.Shared where

import           Data.Char     (intToDigit, toLower, toUpper)
import           System.Random (randomRIO)

-- Take a list of anything and return a random element from it
rIndex :: [a] -> IO a
rIndex arr = randomRIO (0, length arr - 1)
  >>= (\i -> return $ arr !! i)

-- Return the input Char randomly uppercased or lowercased
rCap :: Char -> IO Char
rCap c = rIndex [True,False] >>= (\r -> return $ rCap' r c)
  where
    rCap' :: Bool -> Char -> Char
    rCap' True  c = toUpper c
    rCap' False c = toLower c

-- Return a random character from validChars with random capitalization applied
rChar :: IO Char
rChar = rIndex validChars >>= rCap

-- Return a random character or symbol with random capitalization applied
rCharSym :: IO Char
rCharSym = rIndex (validChars <> validSymbols)>>= rCap

-- Takes any string and returns it in Titlecase
titleCase :: [Char] -> [Char]
titleCase [] = []
titleCase x  = toUpper (head x) : map toLower (tail x)

-- List of valid characters consisting of latin alphabet and numbers
validChars :: [Char]
validChars = validLetters <> fmap intToDigit validNumbers

validNumbers :: [Int]
validNumbers = [1..9]

validLetters :: [Char]
validLetters = ['a'..'z']

validSymbols :: [Char]
validSymbols = ['!', '@', '#', '$', '%', '^', '&', '*']
